@@ -61,6 +61,7 @@ static int cdplayer_timeout_callback(gpointer data);
 static void start_gtcd_cb(GtkWidget *w, gpointer data);
 static void properties_cb (GtkWidget *w, gpointer data);
 static void help_cb (GtkWidget *w, gpointer data);
+static void phelp_cb (GtkWidget *w, gpointer data);
 static void about_cb(GtkWidget *w, gpointer data);
 
 static void applet_change_size(GtkWidget *w, int size, gpointer data);
@@ -126,6 +127,8 @@ applet_fill (PanelApplet *applet)
     GtkTooltips *tooltips;
     int err;
 
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-cdplayer-icon.png");
+    
     cd = g_new0(CDPlayerData, 1);
     cd->panel.applet = GTK_WIDGET (applet);
     
@@ -218,12 +221,14 @@ cdplayer_destroy(GtkWidget * widget, gpointer data)
         g_object_unref (tooltips);
         g_object_set_data (G_OBJECT (cd->panel.applet), "tooltips", NULL);
     }
-    
+   
     if (cd->time_description)
-        g_free(cd->time_description); 
+        g_free(cd->time_description);
     if (cd->track_description)
         g_free(cd->track_description);
+
     g_free (cd->devpath);
+ 
     cd->devpath = NULL;
     g_free(cd);
 }
@@ -263,8 +268,11 @@ start_gtcd_cb(GtkWidget *w, gpointer data)
 static void
 response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
+    if(id == GTK_RESPONSE_HELP){
+         phelp_cb (NULL,data);
+	 return;
+    }
     gtk_widget_destroy (GTK_WIDGET (dialog));
-    
 }
 
 static void
@@ -345,6 +353,7 @@ properties_cb (GtkWidget *w, gpointer data)
     dialog = gtk_dialog_new_with_buttons(_("CD Player Preferences"),
                                          NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                         GTK_STOCK_HELP, GTK_RESPONSE_HELP,
                                          NULL);
     gtk_dialog_set_default_response(GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
     box = GTK_DIALOG(dialog)->vbox;
@@ -399,6 +408,7 @@ help_cb (GtkWidget *w, gpointer data)
     if (error) {
         g_warning ("help error: %s\n", error->message);
         g_error_free (error);
+        error = NULL;
     }
 
     return;
@@ -455,7 +465,6 @@ about_cb(GtkWidget *w, gpointer data)
     	gdk_pixbuf_unref (pixbuf);
 
     gtk_window_set_wmclass (GTK_WINDOW (about), "cd player", "CD Player");
-    gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-cdplayer-icon.png");	
     g_signal_connect (G_OBJECT(about), "destroy",
                       G_CALLBACK(gtk_widget_destroyed), &about);
     gtk_widget_show (about);
@@ -733,6 +742,8 @@ cd_panel_update(GtkWidget * cdplayer, CDPlayerData * cd)
             _("Track number"), cd->track_description);
         g_free (cd->time_description);
         g_free (cd->track_description);
+        cd->time_description = NULL;
+        cd->track_description = NULL;
     }
     else
     {
@@ -902,3 +913,17 @@ set_atk_relation(GtkWidget *label, GtkWidget *widget)
     atk_relation_set_add(relation_set, relation);
     g_object_unref(G_OBJECT (relation));
 }
+
+static void
+phelp_cb (GtkWidget *w, gpointer data)
+{
+    GError *error = NULL;
+    gnome_help_display ("cdplayer", "cdplayer-usage", &error);
+    
+    if (error) {
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
+    return;
+}
