@@ -135,7 +135,7 @@ static IconData icon_list[] = {
 	 NULL}
 };
 
-static gint icon_list_count = 5;
+static gint icon_list_count = 6;
 
 /* Bonobo Verbs for our popup menu */
 static const BonoboUIVerb applet_menu_verbs[] = {
@@ -180,7 +180,9 @@ applet_fill (PanelApplet *applet)
 	DriveData *dd;
 	BonoboUIComponent *component;
 	gchar *tmp_path;
-
+	
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/drivemount-applet.png");
+	
 	panel_applet_add_preferences (applet,
 				      "/schemas/apps/drivemount-applet/prefs",
 				      NULL);
@@ -189,6 +191,7 @@ applet_fill (PanelApplet *applet)
 	gtk_container_add (GTK_CONTAINER (applet), dd->button);
 
 	dd->applet = GTK_WIDGET (applet);
+	dd->tooltips = gtk_tooltips_new ();
 	dd->orient = panel_applet_get_orient (PANEL_APPLET (applet));
 	dd->sizehint = panel_applet_get_size (PANEL_APPLET (applet));
 	g_signal_connect (G_OBJECT (dd->button), "button_press_event",
@@ -402,26 +405,50 @@ static void
 about_cb (PanelApplet *widget, gpointer data)
 {
 	static GtkWidget *about = NULL;
-
+   	GdkPixbuf        *pixbuf;
+   	GError           *error = NULL;
+   	gchar            *file;
+	
 	static const gchar *authors[] = {
 		"John Ellis <johne@bellatlantic.net>",
 		"Chris Phelps <chicane@renient.com>",
 		NULL
 	};
 
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
+
 	if (about != NULL) {
 		gdk_window_show (about->window);
 		gdk_window_raise (about->window);
 		return;
 	}
 
-	about = gnome_about_new (_("Drive Mount Applet"), VERSION,
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "drivemount-applet.png", FALSE, NULL);
+   	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+   	g_free (file);
+   
+   	if (error) {
+   		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
+
+	about = gnome_about_new (_("Disk Mounter"), VERSION,
 				 _("(C) 1999-2001 The GNOME Hackers\n"),
 				 _
 				 ("Applet for mounting and unmounting block volumes."),
-				 authors, NULL, NULL, NULL);
-
-	g_signal_connect (G_OBJECT (about), "destroy",
+				 authors,
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 pixbuf);
+	if (pixbuf) 
+   		gdk_pixbuf_unref (pixbuf);
+   
+   	gtk_window_set_wmclass (GTK_WINDOW (about), "disk mounter", "Disk Mounter");
+   	g_signal_connect (G_OBJECT (about), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
 }
@@ -613,7 +640,7 @@ update_pixmap (DriveData *dd, gint t)
 		text = _(" not mounted");
 	}
 	tiptext = g_strconcat (dd->mount_point, text, NULL);
-	/* applet_widget_set_tooltip(APPLET_WIDGET(dd->applet), tiptext); */
+	gtk_tooltips_set_tip (dd->tooltips, dd->applet, tiptext, NULL);
 	g_free (tiptext);
 }
 
@@ -770,24 +797,27 @@ eject (DriveData *dd)
 
 	if (dd->mounted) {
 		ml = popen ("mount", "r");
-		while (fgets (buffer, sizeof (buffer), ml)) {
+		while (ml && fgets (buffer, sizeof (buffer), ml)) {
 			if (sscanf (buffer, "%255s %*s %255s", dn, mp) == 2 &&
 			    (mp && strcmp (mp, dd->mount_point) == 0)) {
 				found = TRUE;
 				break;
 			}
 		}
-		pclose (ml);
+		if (ml)
+			pclose (ml);
 	} else {
 		ml = fopen ("/etc/fstab", "r");
-		while (fgets (buffer, sizeof (buffer), ml)) {
+		
+		while (ml && fgets (buffer, sizeof (buffer), ml)) {
 			if (sscanf (buffer, "%255s %255s", dn, mp) == 2 &&
 			    strcmp (mp, dd->mount_point) == 0) {
 				found = TRUE;
 				break;
 			}
 		}
-		fclose (ml);
+		if (ml)
+			fclose (ml);
 	}
 
 	if (!found) {		/* mp != dd->mount_point */
