@@ -309,6 +309,8 @@ redraw_applet(MCData *mcdata)
         _("Click this button for the list of previous commands"));
     set_atk_name_description(GTK_WIDGET(applet), _("Mini-Commander applet"),
         _("This applet adds a command line to the panel"));
+    
+    gtk_tooltips_set_tip (tooltips, GTK_WIDGET (applet),  _("Command Line"), NULL);
 	
     /* add buttons into frame */
     frame = gtk_frame_new(NULL);
@@ -352,8 +354,6 @@ redraw_applet(MCData *mcdata)
 		    gtk_container_add(GTK_CONTAINER(frame2), handle);
 		}
 	    
-	    gtk_tooltips_set_tip (tooltips, GTK_WIDGET (applet),  _("Command Line"), NULL);
-	    
 	    if (prop->show_frame)
 		gtk_box_pack_start(GTK_BOX(mcdata->applet_inner_vbox), frame2, TRUE, TRUE, 0);
 	    else
@@ -403,6 +403,8 @@ mini_commander_applet_fill(PanelApplet *applet)
 {
     MCData *mcdata;
     
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-mini-commander.png");
+    
     panel_applet_add_preferences (applet, "/schemas/apps/mini-commander/prefs", NULL);
     
     mcdata = g_new0 (MCData, 1);
@@ -461,7 +463,7 @@ mini_commander_applet_factory(PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MiniCommanderApplet_Factory",
 			     PANEL_TYPE_APPLET,
-                             "Mini-Commander",
+                             "command-line",
                              "0",
                              mini_commander_applet_factory,
                              NULL)
